"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtSql import *
import enum


class QSqlRelationalTableModel(QSqlTableModel):
    """
    https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html

    **Detailed Description**

    QSqlRelationalTableModel acts like **QSqlTableModel** , but allows columns
    to be set as foreign keys into other database tables.

    ![](images/noforeignkeys.png)![](images/foreignkeys.png)

    The screenshot on the left shows a plain **QSqlTableModel**  in a
    **QTableView** . Foreign keys (`city` and `country`) aren't resolved to
    human-readable values. The screenshot on the right shows a
    QSqlRelationalTableModel, with foreign keys resolved into human-readable
    text strings.

    The following code snippet shows how the QSqlRelationalTableModel was set
    up:

    model->setTable("employee");

            model->setRelation(2,
    **QSqlRelation** ("city", "id", "name"));
            model->setRelation(3,
    **QSqlRelation** ("country", "id", "name"));

    The **setRelation** () function calls establish a relationship between two
    tables. The first call specifies that column 2 in table `employee` is a
    foreign key that maps with field `id` of table `city`, and that the view
    should present the `city`'s `name` field to the user. The second call does
    something similar with column 3.

    If you use a read-write QSqlRelationalTableModel, you probably want to use
    **QSqlRelationalDelegate**  on the view. Unlike the default delegate,
    **QSqlRelationalDelegate**  provides a combobox for fields that are foreign
    keys into other tables. To use the class, simply call
    **QAbstractItemView::setItemDelegate** () on the view with an instance of
    **QSqlRelationalDelegate** :

    std::unique_ptr<**QTableView** > view{new **QTableView** };
    view->setModel(model);
            view->setItemDelegate(new
    **QSqlRelationalDelegate** (view.get()));

    The **relationaltablemodel**  example illustrates how to use
    QSqlRelationalTableModel in conjunction with **QSqlRelationalDelegate**  to
    provide tables with foreign key support.

    ![](images/relationaltable.png)

    Notes:

    * The table must have a primary key declared.
      * The table's primary key
    may not contain a relation to another table.
      * If a relational table
    contains keys that refer to non-existent rows in the referenced table, the
    rows containing the invalid keys will not be exposed through the model. The
    user or the database is responsible for keeping referential integrity.
      *
    If a relation's display column name is also used as a column name in the
    relational table, or if it is used as display column name in more than one
    relation it will be aliased. The alias is the relation's table name, display
    column name and a unique id joined by an underscore (e.g.
    tablename_columnname_id). **QSqlRecord::fieldName** () will return the
    aliased column name. All occurrences of the duplicate display column name
    are aliased when duplication is detected, but no aliasing is done to the
    column names in the main table. The aliasing doesn't affect **QSqlRelation**
    , so **QSqlRelation::displayColumn** () will return the original display
    column name.
      * The reference table name is aliased. The alias is the word
    "relTblAl" and the relationed column index joined by an underscore (e.g.
    relTblAl_2). The alias can be used to filter the table (For example,
    setFilter("relTblAl_2='Oslo' OR relTblAl_3='USA'")).
      * When using
    **setData** () the role should always be **Qt::EditRole** , and when using
    **data** () the role should always be **Qt::DisplayRole** .

    **See also** **QSqlRelation** , **QSqlRelationalDelegate** , and
    **Relational Table Model Example** .
    """

    class JoinMode(enum.Enum):
        InnerJoin: QSqlRelationalTableModel = ...
        LeftJoin: QSqlRelationalTableModel = ...

    def __init__(
        self, parent: typing.Optional[QtCore.QObject] = ..., db: QSqlDatabase = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#QSqlRelationalTable
        Model

        **QSqlRelationalTableModel::QSqlRelationalTableModel(QObject * parent =
        nullptr, const QSqlDatabase & db = QSqlDatabase())**

        Creates an empty QSqlRelationalTableModel and sets the parent to
        **parent** and the database connection to **db**. If **db** is not
        valid, the default database connection will be used.
        """
        ...

    def setJoinMode(self, joinMode: "QSqlRelationalTableModel.JoinMode") -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#setJoinMode

        **void
        QSqlRelationalTableModel::setJoinMode(QSqlRelationalTableModel::JoinMode
        joinMode )**

        Sets the SQL **joinMode** to show or hide rows with NULL foreign keys.
        In **InnerJoin**  mode (the default) these rows will not be shown: use
        the **LeftJoin**  mode if you want to show them.

        **See also** **QSqlRelationalTableModel::JoinMode** .
        """
        ...

    def insertRowIntoTable(self, values: QSqlRecord) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#insertRowIntoTable

        **[override virtual protected] bool
        QSqlRelationalTableModel::insertRowIntoTable(const QSqlRecord & values
        )**

        Reimplements: **QSqlTableModel::insertRowIntoTable** (const QSqlRecord
        &values).
        """
        ...

    def orderByClause(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#orderByClause

        **[override virtual protected] QString
        QSqlRelationalTableModel::orderByClause() const**

        Reimplements: **QSqlTableModel::orderByClause() const** .
        """
        ...

    def updateRowInTable(self, row: int, values: QSqlRecord) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#updateRowInTable

        **[override virtual protected] bool
        QSqlRelationalTableModel::updateRowInTable(int row , const QSqlRecord &
        values )**

        Reimplements: **QSqlTableModel::updateRowInTable** (int row, const
        QSqlRecord &values).
        """
        ...

    def selectStatement(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#selectStatement

        **[override virtual protected] QString
        QSqlRelationalTableModel::selectStatement() const**

        Reimplements: **QSqlTableModel::selectStatement() const** .
        """
        ...

    def removeColumns(
        self, column: int, count: int, parent: QtCore.QModelIndex = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#removeColumns

        **[override virtual] bool QSqlRelationalTableModel::removeColumns(int
        column , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QSqlTableModel::removeColumns** (int column, int count,
        const QModelIndex &parent).
        """
        ...

    def revertRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#revertRow

        **[override virtual slot] void QSqlRelationalTableModel::revertRow(int
        row )**

        Reimplements: **QSqlTableModel::revertRow** (int row).
        """
        ...

    def relationModel(self, column: int) -> QSqlTableModel:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#relationModel

        **[virtual] QSqlTableModel *QSqlRelationalTableModel::relationModel(int
        column ) const**

        Returns a **QSqlTableModel**  object for accessing the table for which
        **column** is a foreign key, or `nullptr` if there is no relation for
        the given **column**.

        The returned object is owned by the **QSqlRelationalTableModel** .

        **See also** **setRelation** () and **relation** ().
        """
        ...

    def relation(self, column: int) -> QSqlRelation:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#relation

        **QSqlRelation QSqlRelationalTableModel::relation(int column ) const**

        Returns the relation for the column **column** , or an invalid relation
        if no relation is set.

        **See also** **setRelation** () and **QSqlRelation::isValid** ().
        """
        ...

    def setRelation(self, column: int, relation: QSqlRelation) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#setRelation

        **[virtual] void QSqlRelationalTableModel::setRelation(int column ,
        const QSqlRelation & relation )**

        Lets the specified **column** be a foreign index specified by
        **relation**.

        Example:

        model->setTable("employee");

                model->setRelation(2,
        **QSqlRelation** ("city", "id", "name"));

        The setRelation() call specifies that column 2 in table `employee` is a
        foreign key that maps with field `id` of table `city`, and that the view
        should present the `city`'s `name` field to the user.

        Note: The table's primary key may not contain a relation to another
        table.

        **See also** **relation** ().
        """
        ...

    def setTable(self, tableName: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#setTable

        **[override virtual] void QSqlRelationalTableModel::setTable(const
        QString & table )**

        Reimplements: **QSqlTableModel::setTable** (const QString &tableName).
        """
        ...

    def select(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#select

        **[override virtual] bool QSqlRelationalTableModel::select()**

        Reimplements: **QSqlTableModel::select** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#clear

        **[override virtual] void QSqlRelationalTableModel::clear()**

        Reimplements: **QSqlTableModel::clear** ().
        """
        ...

    def setData(
        self, item: QtCore.QModelIndex, value: typing.Any, role: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#setData

        **[override virtual] bool QSqlRelationalTableModel::setData(const
        QModelIndex & index , const QVariant & value , int role =
        Qt::EditRole)**

        Reimplements: **QSqlTableModel::setData** (const QModelIndex &index,
        const QVariant &value, int role).

        Sets the data for the **role** in the item with the specified **index**
        to the **value** given. Depending on the edit strategy, the value might
        be applied to the database at once, or it may be cached in the model.

        Returns `true` if the value could be set, or false on error (for
        example, if **index** is out of bounds).

        For relational columns, **value** must be the index, not the display
        value. The index must also exist in the referenced table, otherwise the
        function returns `false`.

        **See also** **editStrategy** (), **data** (), **submit** (), and
        **revertRow** ().
        """
        ...

    def data(self, item: QtCore.QModelIndex, role: int = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlrelationaltablemodel.html#data

        **[override virtual] QVariant QSqlRelationalTableModel::data(const
        QModelIndex & index , int role = Qt::DisplayRole) const**

        Reimplements: **QSqlTableModel::data(const QModelIndex &index, int role)
        const** .

        **See also** **setData** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDBusSignature(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbussignature.html

    **Detailed Description**

    **See also** **The Qt D-Bus Type System** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#QDBusSignature

        **QDBusSignature::QDBusSignature()**

        Constructs a new signature.

        **See also** **setSignature** ().
        """
        ...

    @typing.overload
    def __init__(self, dBusSignature: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#QDBusSignature-1

        **QDBusSignature::QDBusSignature(const char * signature )**

        Constructs a new signature from the given **signature**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDBusSignature") -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#QDBusSignature-2

        **QDBusSignature::QDBusSignature(QLatin1String signature )**

        Constructs a new signature from the given **signature**.
        """
        ...

    def swap(self, other: "QDBusSignature") -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#swap

        **void QDBusSignature::swap(QDBusSignature & other )**

        Swaps this **QDBusSignature**  instance with **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def setSignature(self, dBusSignature: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#setSignature

        **void QDBusSignature::setSignature(const QString & signature )**

        Assigns the value of the given **signature** to this signature.

        **See also** **signature** ().
        """
        ...

    def signature(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#signature

        **QString QDBusSignature::signature() const**

        Returns this signature.

        **See also** **setSignature** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtQml import *


class QQmlEngineExtensionPlugin(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlengineextensionplugin.html

    **Detailed Description**

    **QQmlEngineExtensionPlugin**  is a plugin interface that makes it possible
    to create QML extensions that can be loaded dynamically into QML
    applications. These extensions allow custom QML types to be made available
    to the QML engine.

    To write a QML extension plugin:

    1. Subclass **QQmlEngineExtensionPlugin**  and use the **Q_PLUGIN_METADATA**
    () macro to register the plugin with the Qt meta object system.
      2. Use the
    **QML_ELEMENT**  and **QML_NAMED_ELEMENT** () macros to declare QML types.
    3. Write a project file for the plugin. Add:
        * `CONFIG += qmltypes` to
    instruct the build system to generate QML types.
        * `QML_IMPORT_NAME =
    <my.import.name>` to specify the import name.
        *
    `QML_IMPORT_MAJOR_VERSION = <version>` to specify the import major version.
    4. Create a **qmldir file**  to describe the plugin

    QML extension plugins are for either application-specific or library-like
    plugins. Library plugins should limit themselves to registering types, as
    any manipulation of the engine's root context may cause conflicts or other
    issues in the library user's code.

    The linker might erroneously remove the generated type registration function
    as an optimization. You can prevent that by declaring a synthetic volatile
    pointer to the function somewhere in your code. If your module is called
    "my.module", you would add the forward declaration in global scope:

    void qml_register_types_my_module();

    Then add the following snippet of code in the implementation of any function
    that's part of the same binary as the registration:

    volatile auto registration = &qml_register_types_my_module;
    Q_UNUSED(registration);

    **TimeExample QML extension plugin**

    Suppose there is a new `TimeModel` C++ class that should be made available
    as a new QML type. It provides the current time through `hour` and `minute`
    properties. It declares a QML type called `Time` via **QML_NAMED_ELEMENT**
    ().

    class TimeModel : public **QObject**
        {
            Q_OBJECT
    Q_PROPERTY(int hour READ hour NOTIFY timeChanged)
            Q_PROPERTY(int
    minute READ minute NOTIFY timeChanged)
            QML_NAMED_ELEMENT(Time)
    ...

    To make this type available, we create a plugin class named
    `QExampleQmlPlugin` which is a subclass of **QQmlEngineExtensionPlugin** .
    It uses the **Q_PLUGIN_METADATA** () macro in the class definition to
    register the plugin with the Qt meta object system using a unique identifier
    for the plugin.

    class QExampleQmlPlugin : public QQmlEngineExtensionPlugin
        {
    Q_OBJECT
            Q_PLUGIN_METADATA(IID QQmlEngineExtensionInterface_iid)
    };

    **Project settings for the plugin**

    Additionally, the project file (`.pro`) defines the project as a plugin
    library, specifies it should be built into the `imports/TimeExample`
    directory, and registers the plugin target name and various other details:

    TEMPLATE = lib
        CONFIG += qt plugin qmltypes
        QT += qml
    QML_IMPORT_NAME = TimeExample
        QML_IMPORT_MAJOR_VERSION = 1
    DESTDIR = imports/$$QML_IMPORT_NAME
        TARGET  = qmlqtimeexampleplugin
    SOURCES += qexampleqmlplugin.cpp

    This registers the `TimeModel` class with the import `TimeExample 1.0`, as a
    QML type called `Time`. The **Defining QML Types from C++**  article has
    more information about registering C++ types for usage in QML.

    **Plugin definition in the qmldir**

    Finally, a **qmldir file**  is required in the `imports/TimeExample`
    directory to describe the plugin and the types that it exports. The plugin
    includes a `Clock.qml` file along with the `qmlqtimeexampleplugin` that is
    built by the project (as shown above in the `.pro` file) so both of these
    need to be specified in the `qmldir` file:

    module TimeExample
        Clock 1.0 Clock.qml
        plugin qmlqtimeexampleplugin

    To make things easier for this example, the TimeExample source directory is
    in `imports/TimeExample`, and we build **in-source** . However, the
    structure of the source directory is not so important, as the `qmldir` file
    can specify paths to installed QML files.

    What is important is the name of the directory that the qmldir is installed
    into. When the user imports our module, the QML engine uses the **module
    identifier**  (`TimeExample`) to find the plugin, and so the directory in
    which it is installed must match the module identifier.

    Once the project is built and installed, the new `Time` component is
    accessible by any QML component that imports the `TimeExample` module

    import TimeExample 1.0 // import types from the plugin

        Clock { //
    this class is defined in QML (imports/TimeExample/Clock.qml)
    Time { // this class is defined in C++ (plugin.cpp)
                id: time
    }

            hours: time.hour
            minutes: time.minute

        }

    The full source code is available in the **plugins example** .

    The **Writing QML Extensions with C++**  tutorial also contains a chapter on
    creating QML plugins.

    **See also** **QQmlEngine::importPlugin** () and **How to Create Qt
    Plugins** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengineextensionplugin.html#QQmlEngineExtensio
        nPlugin-2

        **QQmlEngineExtensionPlugin::QQmlEngineExtensionPlugin(QObject * parent
        = nullptr)**

        Constructs a QML extension plugin with the given **parent**.

        Note that this constructor is invoked automatically by the
        **Q_PLUGIN_METADATA** () macro, so there is no need for calling it
        explicitly.
        """
        ...

    def initializeEngine(self, engine: QQmlEngine, uri: str) -> None:
        """
        https://doc.qt.io/qt-6/qqmlengineextensionplugin.html#initializeEngine

        **[override virtual] void
        QQmlEngineExtensionPlugin::initializeEngine(QQmlEngine * engine , const
        char * uri )**

        Initializes the extension from the **uri** using the **engine**. Here an
        application plugin might, for example, expose some data or objects to
        QML, as context properties on the engine's root context.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QEasingCurve(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qeasingcurve.html

    **Detailed Description**

    Easing curves describe a function that controls how the speed of the
    interpolation between 0 and 1 should be. Easing curves allow transitions
    from one value to another to appear more natural than a simple constant
    speed would allow. The QEasingCurve class is usually used in conjunction
    with the **QVariantAnimation**  and **QPropertyAnimation**  classes but can
    be used on its own. It is usually used to accelerate the interpolation from
    zero velocity (ease in) or decelerate to zero velocity (ease out). Ease in
    and ease out can also be combined in the same easing curve.

    To calculate the speed of the interpolation, the easing curve provides the
    function **valueForProgress** (), where the **progress** argument specifies
    the progress of the interpolation: 0 is the start value of the
    interpolation, 1 is the end value of the interpolation. The returned value
    is the effective progress of the interpolation. If the returned value is the
    same as the input value for all input values the easing curve is a linear
    curve. This is the default behaviour.

    For example,

    **QEasingCurve**  easing(**QEasingCurve** ::InOutQuad);

            for
    (**qreal**  t = 0.0; t < 1.0; t += 0.1)
                **qWarning** () <<
    "Effective progress" << t << "is"
                           <<
    easing.valueForProgress(t);

    will print the effective progress of the interpolation between 0 and 1.

    When using a **QPropertyAnimation** , the associated easing curve will be
    used to control the progress of the interpolation between startValue and
    endValue:

    **QPropertyAnimation**  animation;
            animation.setStartValue(0);
    animation.setEndValue(1000);
            animation.setDuration(1000);
    animation.setEasingCurve(**QEasingCurve** ::InOutQuad);

    The ability to set an amplitude, overshoot, or period depends on the
    QEasingCurve type. Amplitude access is available to curves that behave as
    springs such as elastic and bounce curves. Changing the amplitude changes
    the height of the curve. Period access is only available to elastic curves
    and setting a higher period slows the rate of bounce. Only curves that have
    "boomerang" behaviors such as the **InBack** , **OutBack** , **InOutBack** ,
    and **OutInBack**  have overshoot settings. These curves will interpolate
    beyond the end points and return to the end point, acting similar to a
    boomerang.

    The **Easing Curves Example**  contains samples of QEasingCurve types and
    lets you change the curve settings.
    """

    class Type(enum.Enum):
        Linear: QEasingCurve = ...
        InQuad: QEasingCurve = ...
        OutQuad: QEasingCurve = ...
        InOutQuad: QEasingCurve = ...
        OutInQuad: QEasingCurve = ...
        InCubic: QEasingCurve = ...
        OutCubic: QEasingCurve = ...
        InOutCubic: QEasingCurve = ...
        OutInCubic: QEasingCurve = ...
        InQuart: QEasingCurve = ...
        OutQuart: QEasingCurve = ...
        InOutQuart: QEasingCurve = ...
        OutInQuart: QEasingCurve = ...
        InQuint: QEasingCurve = ...
        OutQuint: QEasingCurve = ...
        InOutQuint: QEasingCurve = ...
        OutInQuint: QEasingCurve = ...
        InSine: QEasingCurve = ...
        OutSine: QEasingCurve = ...
        InOutSine: QEasingCurve = ...
        OutInSine: QEasingCurve = ...
        InExpo: QEasingCurve = ...
        OutExpo: QEasingCurve = ...
        InOutExpo: QEasingCurve = ...
        OutInExpo: QEasingCurve = ...
        InCirc: QEasingCurve = ...
        OutCirc: QEasingCurve = ...
        InOutCirc: QEasingCurve = ...
        OutInCirc: QEasingCurve = ...
        InElastic: QEasingCurve = ...
        OutElastic: QEasingCurve = ...
        InOutElastic: QEasingCurve = ...
        OutInElastic: QEasingCurve = ...
        InBack: QEasingCurve = ...
        OutBack: QEasingCurve = ...
        InOutBack: QEasingCurve = ...
        OutInBack: QEasingCurve = ...
        InBounce: QEasingCurve = ...
        OutBounce: QEasingCurve = ...
        InOutBounce: QEasingCurve = ...
        OutInBounce: QEasingCurve = ...
        InCurve: QEasingCurve = ...
        OutCurve: QEasingCurve = ...
        SineCurve: QEasingCurve = ...
        CosineCurve: QEasingCurve = ...
        BezierSpline: QEasingCurve = ...
        TCBSpline: QEasingCurve = ...
        Custom: QEasingCurve = ...

    @typing.overload
    def __init__(self, type: "QEasingCurve.Type" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#QEasingCurve

        **QEasingCurve::QEasingCurve(QEasingCurve::Type type = Linear)**

        Constructs an easing curve of the given **type**.
        """
        ...

    @typing.overload
    def __init__(
        self, other: typing.Union["QEasingCurve", "QEasingCurve.Type"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#QEasingCurve-1

        **QEasingCurve::QEasingCurve(const QEasingCurve & other )**

        Construct a copy of **other**.
        """
        ...

    def toCubicSpline(self) -> typing.List["QPointF"]:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#toCubicSpline

        **[since 5.0] QList<QPointF> QEasingCurve::toCubicSpline() const**

        Returns the cubicBezierSpline that defines a custom easing curve. If the
        easing curve does not have a custom bezier easing curve the list is
        empty.

        This function was introduced in Qt 5.0.
        """
        ...

    def addTCBSegment(self, nextPoint: "QPointF", t: float, c: float, b: float) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#addTCBSegment

        **void QEasingCurve::addTCBSegment(const QPointF & nextPoint , qreal t ,
        qreal c , qreal b )**

        Adds a segment of a TCB bezier spline to define a custom easing curve.
        It is only applicable if **type** () is **QEasingCurve::TCBSpline** .
        The spline has to start explicitly at (0.0, 0.0) and has to end at (1.0,
        1.0) to be a valid easing curve. The tension **t** changes the length of
        the tangent vector. The continuity **c** changes the sharpness in change
        between the tangents. The bias **b** changes the direction of the
        tangent vector. **nextPoint** is the sample position. All three
        parameters are valid between -1 and 1 and define the tangent of the
        control point. If all three parameters are 0 the resulting spline is a
        Catmull-Rom spline. The begin and endpoint always have a bias of -1 and
        1, since the outer tangent is not defined.
        """
        ...

    def addCubicBezierSegment(
        self, c1: "QPointF", c2: "QPointF", endPoint: "QPointF"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#addCubicBezierSegment

        **void QEasingCurve::addCubicBezierSegment(const QPointF & c1 , const
        QPointF & c2 , const QPointF & endPoint )**

        Adds a segment of a cubic bezier spline to define a custom easing curve.
        It is only applicable if **type** () is **QEasingCurve::BezierSpline** .
        Note that the spline implicitly starts at (0.0, 0.0) and has to end at
        (1.0, 1.0) to be a valid easing curve. **c1** and **c2** are the control
        points used for drawing the curve. **endPoint** is the endpoint of the
        curve.
        """
        ...

    def swap(self, other: "QEasingCurve") -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#swap

        **[since 5.0] void QEasingCurve::swap(QEasingCurve & other )**

        Swaps curve **other** with this curve. This operation is very fast and
        never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def valueForProgress(self, progress: float) -> float:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#valueForProgress

        **qreal QEasingCurve::valueForProgress(qreal progress ) const**

        Return the effective progress for the easing curve at **progress**.
        Whereas **progress** must be between 0 and 1, the returned effective
        progress can be outside those bounds. For example,
        **QEasingCurve::InBack**  will return negative values in the beginning
        of the function.
        """
        ...

    def customType(self) -> typing.Callable[[float], float]:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#customType

        **QEasingCurve::EasingFunction QEasingCurve::customType() const**

        Returns the function pointer to the custom easing curve. If **type** ()
        does not return **QEasingCurve::Custom** , this function will return 0.

        **See also** **setCustomType** ().
        """
        ...

    def setCustomType(self, func: typing.Callable[[float], float]) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#setCustomType

        **void QEasingCurve::setCustomType(QEasingCurve::EasingFunction func )**

        Sets a custom easing curve that is defined by the user in the function
        **func**. The signature of the function is qreal myEasingFunction(qreal
        progress), where **progress** and the return value are considered to be
        normalized between 0 and 1. (In some cases the return value can be
        outside that range) After calling this function **type** () will return
        **QEasingCurve::Custom** . **func** cannot be zero.

        **See also** **customType** () and **valueForProgress** ().
        """
        ...

    def setType(self, type: "QEasingCurve.Type") -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#setType

        **void QEasingCurve::setType(QEasingCurve::Type type )**

        Sets the type of the easing curve to **type**.

        **See also** **type** ().
        """
        ...

    def type(self) -> "QEasingCurve.Type":
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#type

        **QEasingCurve::Type QEasingCurve::type() const**

        Returns the type of the easing curve.

        **See also** **setType** ().
        """
        ...

    def setOvershoot(self, overshoot: float) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#setOvershoot

        **void QEasingCurve::setOvershoot(qreal overshoot )**

        Sets the overshoot to **overshoot**.

        0 produces no overshoot, and the default value of 1.70158 produces an
        overshoot of 10 percent.

        **See also** **overshoot** ().
        """
        ...

    def overshoot(self) -> float:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#overshoot

        **qreal QEasingCurve::overshoot() const**

        Returns the overshoot. This is not applicable for all curve types. It is
        only applicable if **type** () is **QEasingCurve::InBack** ,
        **QEasingCurve::OutBack** , **QEasingCurve::InOutBack**  or
        **QEasingCurve::OutInBack** .

        **See also** **setOvershoot** ().
        """
        ...

    def setPeriod(self, period: float) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#setPeriod

        **void QEasingCurve::setPeriod(qreal period )**

        Sets the period to **period**. Setting a small period value will give a
        high frequency of the curve. A large period will give it a small
        frequency.

        **See also** **period** ().
        """
        ...

    def period(self) -> float:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#period

        **qreal QEasingCurve::period() const**

        Returns the period. This is not applicable for all curve types. It is
        only applicable if **type** () is **QEasingCurve::InElastic** ,
        **QEasingCurve::OutElastic** , **QEasingCurve::InOutElastic**  or
        **QEasingCurve::OutInElastic** .

        **See also** **setPeriod** ().
        """
        ...

    def setAmplitude(self, amplitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#setAmplitude

        **void QEasingCurve::setAmplitude(qreal amplitude )**

        Sets the amplitude to **amplitude**.

        This will set the amplitude of the bounce or the amplitude of the
        elastic "spring" effect. The higher the number, the higher the
        amplitude.

        **See also** **amplitude** ().
        """
        ...

    def amplitude(self) -> float:
        """
        https://doc.qt.io/qt-6/qeasingcurve.html#amplitude

        **qreal QEasingCurve::amplitude() const**

        Returns the amplitude. This is not applicable for all curve types. It is
        only applicable for bounce and elastic curves (curves of **type** ()
        **QEasingCurve::InBounce** , **QEasingCurve::OutBounce** ,
        **QEasingCurve::InOutBounce** , **QEasingCurve::OutInBounce** ,
        **QEasingCurve::InElastic** , **QEasingCurve::OutElastic** ,
        **QEasingCurve::InOutElastic**  or **QEasingCurve::OutInElastic** ).

        **See also** **setAmplitude** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6.QtNetwork import *
import enum


class QOcspRevocationReason(enum.Enum):
    None_: QOcspRevocationReason = ...
    Unspecified: QOcspRevocationReason = ...
    KeyCompromise: QOcspRevocationReason = ...
    CACompromise: QOcspRevocationReason = ...
    AffiliationChanged: QOcspRevocationReason = ...
    Superseded: QOcspRevocationReason = ...
    CessationOfOperation: QOcspRevocationReason = ...
    CertificateHold: QOcspRevocationReason = ...
    RemoveFromCRL: QOcspRevocationReason = ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QCheckBox(QAbstractButton):
    """
    https://doc.qt.io/qt-6/qcheckbox.html

    **Detailed Description**

    ![](images/windows-checkbox.png)

    A QCheckBox is an option button that can be switched on (checked) or off
    (unchecked). Checkboxes are typically used to represent features in an
    application that can be enabled or disabled without affecting others.
    Different types of behavior can be implemented. For example, a
    **QButtonGroup**  can be used to group check buttons logically, allowing
    exclusive checkboxes. However, **QButtonGroup**  does not provide any visual
    representation.

    The image below further illustrates the differences between exclusive and
    non-exclusive checkboxes.

    ![](images/checkboxes-exclusive.png)![](images/checkboxes-non-exclusive.png)

    Whenever a checkbox is checked or cleared, it emits the signal
    **stateChanged** (). Connect to this signal if you want to trigger an action
    each time the checkbox changes state. You can use **isChecked** () to query
    whether or not a checkbox is checked.

    In addition to the usual checked and unchecked states, QCheckBox optionally
    provides a third state to indicate "no change". This is useful whenever you
    need to give the user the option of neither checking nor unchecking a
    checkbox. If you need this third state, enable it with **setTristate** (),
    and use **checkState** () to query the current toggle state.

    Just like **QPushButton** , a checkbox displays text, and optionally a small
    icon. The icon is set with **setIcon** (). The text can be set in the
    constructor or with **setText** (). A shortcut key can be specified by
    preceding the preferred character with an ampersand. For example:

    **QCheckBox**  *checkbox = new **QCheckBox** ("C&ase sensitive", this);

    In this example, the shortcut is **Alt+A**. See the **QShortcut**
    documentation for details. To display an actual ampersand, use '&&'.

    Important inherited functions: **text** (), **setText** (), **text** (),
    pixmap(), setPixmap(), accel(), setAccel(), isToggleButton(), **setDown**
    (), **isDown** (), isOn(), **checkState** (), **autoRepeat** (),
    isExclusiveToggle(), **group** (), **setAutoRepeat** (), **toggle** (),
    **pressed** (), **released** (), **clicked** (), **toggled** (),
    **checkState** (), and **stateChanged** ().

    **See also** **QAbstractButton** , **QRadioButton** , and **GUI Design
    Handbook: Check Box** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#QCheckBox

        **QCheckBox::QCheckBox(QWidget * parent = nullptr)**

        Constructs a checkbox with the given **parent** , but with no text.

        **parent** is passed on to the **QAbstractButton**  constructor.
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#QCheckBox-1

        **QCheckBox::QCheckBox(const QString & text , QWidget * parent =
        nullptr)**

        Constructs a checkbox with the given **parent** and **text**.

        **parent** is passed on to the **QAbstractButton**  constructor.
        """
        ...

    def initStyleOption(self, option: "QStyleOptionButton") -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#initStyleOption

        **[virtual protected] void QCheckBox::initStyleOption(QStyleOptionButton
        * option ) const**

        Initializes **option** with the values from this **QCheckBox** . This
        method is useful for subclasses that require a **QStyleOptionButton** ,
        but do not want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#mouseMoveEvent

        **[override virtual protected] void
        QCheckBox::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QAbstractButton::mouseMoveEvent** (QMouseEvent *e).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#paintEvent

        **[override virtual protected] void QCheckBox::paintEvent(QPaintEvent
        *)**

        Reimplements: **QAbstractButton::paintEvent** (QPaintEvent *e).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#event

        **[override virtual protected] bool QCheckBox::event(QEvent * e )**

        Reimplements: **QAbstractButton::event** (QEvent *e).
        """
        ...

    def nextCheckState(self) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#nextCheckState

        **[override virtual protected] void QCheckBox::nextCheckState()**

        Reimplements: **QAbstractButton::nextCheckState** ().
        """
        ...

    def checkStateSet(self) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#checkStateSet

        **[override virtual protected] void QCheckBox::checkStateSet()**

        Reimplements: **QAbstractButton::checkStateSet** ().
        """
        ...

    def hitButton(self, pos: QtCore.QPoint) -> bool:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#hitButton

        **[override virtual protected] bool QCheckBox::hitButton(const QPoint &
        pos ) const**

        Reimplements: **QAbstractButton::hitButton(const QPoint &pos) const** .
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#minimumSizeHint

        **[override virtual] QSize QCheckBox::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def setCheckState(self, state: QtCore.Qt.CheckState) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#setCheckState

        **void QCheckBox::setCheckState(Qt::CheckState state )**

        Sets the checkbox's check state to **state**. If you do not need
        tristate support, you can also use **QAbstractButton::setChecked** (),
        which takes a boolean.

        **See also** **checkState** () and **Qt::CheckState** .
        """
        ...

    def checkState(self) -> QtCore.Qt.CheckState:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#checkState

        **Qt::CheckState QCheckBox::checkState() const**

        Returns the checkbox's check state. If you do not need tristate support,
        you can also use **QAbstractButton::isChecked** (), which returns a
        boolean.

        **See also** **setCheckState** () and **Qt::CheckState** .
        """
        ...

    def isTristate(self) -> bool:
        ...

    def setTristate(self, on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#tristate-prop

        **tristate : bool**

        This property holds whether the checkbox is a tri-state checkbox

        The default is false, i.e., the checkbox has only two states.

        **Access functions:**

        bool **isTristate** () const
        void **setTristate** (bool **y** = true)

        **Member Function Documentation**
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#sizeHint

        **[override virtual] QSize QCheckBox::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcheckbox.html#stateChanged

        **[signal] void QCheckBox::stateChanged(int state )**

        This signal is emitted whenever the checkbox's state changes, i.e.,
        whenever the user checks or unchecks it.

        **state** contains the checkbox's new **Qt::CheckState** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsItemGroup(QGraphicsItem):
    """
    https://doc.qt.io/qt-6/qgraphicsitemgroup.html

    **Detailed Description**

    A QGraphicsItemGroup is a special type of compound item that treats itself
    and all its children as one item (i.e., all events and geometries for all
    children are merged together). It's common to use item groups in
    presentation tools, when the user wants to group several smaller items into
    one big item in order to simplify moving and copying of items.

    If all you want is to store items inside other items, you can use any
    **QGraphicsItem**  directly by passing a suitable parent to
    **setParentItem** ().

    The **boundingRect** () function of QGraphicsItemGroup returns the bounding
    rectangle of all items in the item group. QGraphicsItemGroup ignores the
    ItemIgnoresTransformations flag on its children (i.e., with respect to the
    geometry of the group item, the children are treated as if they were
    transformable).

    There are two ways to construct an item group. The easiest and most common
    approach is to pass a list of items (e.g., all selected items) to
    **QGraphicsScene::createItemGroup** (), which returns a new
    QGraphicsItemGroup item. The other approach is to manually construct a
    QGraphicsItemGroup item, add it to the scene calling
    **QGraphicsScene::addItem** (), and then add items to the group manually,
    one at a time by calling **addToGroup** (). To dismantle ("ungroup") an item
    group, you can either call **QGraphicsScene::destroyItemGroup** (), or you
    can manually remove all items from the group by calling **removeFromGroup**
    ().

    // Group all selected items together
        **QGraphicsItemGroup**  *group =
    scene->createItemGroup(scene->selecteditems());

        // Destroy the
    group, and delete the group item
        scene->destroyItemGroup(group);

    The operation of adding and removing items preserves the items' scene-
    relative position and transformation, as opposed to calling
    **setParentItem** (), where only the child item's parent-relative position
    and transformation are kept.

    The addtoGroup() function reparents the target item to this item group,
    keeping the item's position and transformation intact relative to the scene.
    Visually, this means that items added via **addToGroup** () will remain
    completely unchanged as a result of this operation, regardless of the item
    or the group's current position or transformation; although the item's
    position and matrix are likely to change.

    The **removeFromGroup** () function has similar semantics to
    **setParentItem** (); it reparents the item to the parent item of the item
    group. As with **addToGroup** (), the item's scene-relative position and
    transformation remain intact.

    **See also** **QGraphicsItem**  and **Graphics View Framework** .
    """

    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#QGraphicsItemGroup

        **QGraphicsItemGroup::QGraphicsItemGroup(QGraphicsItem * parent =
        nullptr)**

        Constructs a QGraphicsItemGroup. **parent** is passed to
        **QGraphicsItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#type

        **[override virtual] int QGraphicsItemGroup::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsItemGroup::opaqueArea()
        const**

        Reimplements: **QGraphicsItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#isObscuredBy

        **[override virtual] bool QGraphicsItemGroup::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QGraphicsItem::isObscuredBy(const QGraphicsItem *item)
        const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#paint

        **[override virtual] void QGraphicsItemGroup::paint(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget = nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#boundingRect

        **[override virtual] QRectF QGraphicsItemGroup::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .

        Returns the bounding rect of this group item, and all its children.
        """
        ...

    def removeFromGroup(self, item: QGraphicsItem) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#removeFromGroup

        **void QGraphicsItemGroup::removeFromGroup(QGraphicsItem * item )**

        Removes the specified **item** from this group. The item will be
        reparented to this group's parent item, or to 0 if this group has no
        parent. Its position and transformation relative to the scene will stay
        intact.

        **See also** **addToGroup** () and **QGraphicsScene::destroyItemGroup**
        ().
        """
        ...

    def addToGroup(self, item: QGraphicsItem) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsitemgroup.html#addToGroup

        **void QGraphicsItemGroup::addToGroup(QGraphicsItem * item )**

        Adds the given **item** and item's child items to this item group. The
        item and child items will be reparented to this group, but its position
        and transformation relative to the scene will stay intact.

        **See also** **removeFromGroup** () and
        **QGraphicsScene::createItemGroup** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QExtensionManager(QtCore.QObject, QAbstractExtensionManager):
    """
    https://doc.qt.io/qt-6/qextensionmanager.html

    **Detailed Description**

    In **Qt Designer** the extensions are not created until they are required.
    For that reason, when implementing an extension, you must also create a
    **QExtensionFactory** , i.e a class that is able to make an instance of your
    extension, and register it using **Qt Designer** 's extension manager.

    The registration of an extension factory is typically made in the
    **QDesignerCustomWidgetInterface::initialize** () function:

    void MyPlugin::initialize(**QDesignerFormEditorInterface**  *formEditor)
    {
                    if (initialized)
                        return;
    **QExtensionManager**  *manager = formEditor->extensionManager();
    Q_ASSERT(manager != 0);

                    manager->registerExtensions(new
    MyExtensionFactory(manager),
    Q_TYPEID(**QDesignerTaskMenuExtension** ));

                    initialized
    = true;
                }

    The QExtensionManager is not intended to be instantiated directly. You can
    retrieve an interface to **Qt Designer** 's extension manager using the
    **QDesignerFormEditorInterface::extensionManager** () function. A pointer to
    **Qt Designer** 's current **QDesignerFormEditorInterface**  object
    (`formEditor` in the example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter. When
    implementing a custom widget plugin, you must subclass the
    **QDesignerCustomWidgetInterface**  to expose your plugin to **Qt
    Designer**.

    Then, when an extension is required, **Qt Designer** 's extension manager
    will run through all its registered factories calling
    **QExtensionFactory::createExtension** () for each until the first one that
    is able to create the requested extension for the selected object, is found.
    This factory will then make an instance of the extension.

    There are four available types of extensions in **Qt Designer** :
    **QDesignerContainerExtension**  , **QDesignerMemberSheetExtension** ,
    **QDesignerPropertySheetExtension**  and **QDesignerTaskMenuExtension** .
    **Qt Designer** 's behavior is the same whether the requested extension is
    associated with a container, a member sheet, a property sheet or a task
    menu.

    For a complete example using the QExtensionManager class, see the **Task
    Menu Extension example** . The example shows how to create a custom widget
    plugin for Qt Designer, and how to to use the **QDesignerTaskMenuExtension**
    class to add custom items to **Qt Designer** 's task menu.

    **See also** **QExtensionFactory**  and **QAbstractExtensionManager** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qextensionmanager.html#QExtensionManager

        **QExtensionManager::QExtensionManager(QObject * parent = nullptr)**

        Constructs an extension manager with the given **parent**.
        """
        ...

    def extension(self, object: QtCore.QObject, iid: str) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qextensionmanager.html#extension

        **[override virtual] QObject *QExtensionManager::extension(QObject *
        object , const QString & iid ) const**

        Reimplements: **QAbstractExtensionManager::extension(QObject *object,
        const QString &iid) const** .

        Returns the extension specified by **iid** , for the given **object**.
        """
        ...

    def unregisterExtensions(
        self, factory: QAbstractExtensionFactory, iid: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qextensionmanager.html#unregisterExtensions

        **[override virtual] void
        QExtensionManager::unregisterExtensions(QAbstractExtensionFactory *
        factory , const QString & iid = QString())**

        Reimplements: **QAbstractExtensionManager::unregisterExtensions**
        (QAbstractExtensionFactory *factory, const QString &iid).

        Unregister the extension specified by the given **factory** and
        extension identifier **iid**.
        """
        ...

    def registerExtensions(
        self, factory: QAbstractExtensionFactory, iid: str = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qextensionmanager.html#registerExtensions

        **[override virtual] void
        QExtensionManager::registerExtensions(QAbstractExtensionFactory *
        factory , const QString & iid = QString())**

        Reimplements: **QAbstractExtensionManager::registerExtensions**
        (QAbstractExtensionFactory *factory, const QString &iid).

        Register the extension specified by the given **factory** and extension
        identifier **iid**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTextTableFormat(QTextFrameFormat):
    """
    https://doc.qt.io/qt-6/qtexttableformat.html

    **Detailed Description**

    A table is a group of cells ordered into rows and columns. Each table
    contains at least one row and one column. Each cell contains a block. Tables
    in rich text documents are formatted using the properties defined in this
    class.

    Tables are horizontally justified within their parent frame according to the
    table's alignment. This can be read with the **alignment** () function and
    set with **setAlignment** ().

    Cells within the table are separated by cell spacing. The number of pixels
    between cells is set with **setCellSpacing** () and read with
    **cellSpacing** (). The contents of each cell is surrounded by cell padding.
    The number of pixels between each cell edge and its contents is set with
    **setCellPadding** () and read with **cellPadding** ().

    ![](images/qtexttableformat-cell.png)

    The table's background color can be read with the **background** ()
    function, and can be specified with **setBackground** (). The background
    color of each cell can be set independently, and will control the color of
    the cell within the padded area.

    The table format also provides a way to constrain the widths of the columns
    in the table. Columns can be assigned a fixed width, a variable width, or a
    percentage of the available width (see **QTextLength** ). The **columns** ()
    function returns the number of columns with constraints, and the
    **columnWidthConstraints** () function returns the constraints defined for
    the table. These quantities can also be set by calling
    **setColumnWidthConstraints** () with a list containing new constraints. If
    no constraints are required, **clearColumnWidthConstraints** () can be used
    to remove them.

    **See also** **QTextTable** , **QTextTableCell** , and **QTextLength** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#QTextTableFormat

        **QTextTableFormat::QTextTableFormat()**

        Constructs a new table format object.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTextTableFormat") -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#QTextTableFormat

        **QTextTableFormat::QTextTableFormat()**

        Constructs a new table format object.
        """
        ...

    def borderCollapse(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#borderCollapse

        **[since 5.14] bool QTextTableFormat::borderCollapse() const**

        Returns true if borderCollapse is enabled.

        This function was introduced in Qt 5.14.

        **See also** **setBorderCollapse** ().
        """
        ...

    def setBorderCollapse(self, borderCollapse: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#setBorderCollapse

        **[since 5.14] void QTextTableFormat::setBorderCollapse(bool
        borderCollapse )**

        Enabling **borderCollapse** will have the following implications:

        * The borders and grid of the table will be rendered following the CSS
        table `border-collapse`: `collapse` rules
          * Setting the `border`
        property to a minimum value of `1` will render a one pixel solid inner
        table grid using the **borderBrush**  property and an outer border as
        specified
          * The various border style properties of
        **QTextTableCellFormat**  can be used to customize the grid and have
        precedence over the border and grid of the table
          * The **cellSpacing**
        property will be ignored
          * For print pagination:
            * Columns
        continued on a page will not have their top cell border rendered
            *
        Repeated header rows will always have their bottom cell border rendered

        With **borderCollapse**  disabled, cell borders can still be styled
        using **QTextTableCellFormat**  but styling will be applied only within
        the cell's frame, which is probably not very useful in practice.

        This function was introduced in Qt 5.14.

        **See also** **borderCollapse** (), **setBorder** (), **setBorderBrush**
        (), **setBorderStyle** (), and **QTextTableCellFormat** .
        """
        ...

    def headerRowCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#headerRowCount

        **int QTextTableFormat::headerRowCount() const**

        Returns the number of rows in the table that define the header.

        **See also** **setHeaderRowCount** ().
        """
        ...

    def setHeaderRowCount(self, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#setHeaderRowCount

        **void QTextTableFormat::setHeaderRowCount(int count )**

        Declares the first **count** rows of the table as table header. The
        table header rows get repeated when a table is broken across a page
        boundary.

        **See also** **headerRowCount** ().
        """
        ...

    def setAlignment(self, aalignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#setAlignment

        **void QTextTableFormat::setAlignment(Qt::Alignment alignment )**

        Sets the table's **alignment**.

        **See also** **alignment** ().
        """
        ...

    def setCellPadding(self, apadding: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#setCellPadding

        **void QTextTableFormat::setCellPadding(qreal padding )**

        Sets the cell **padding** for the table. This determines the distance
        between the border of a cell and its contents.

        **See also** **cellPadding** ().
        """
        ...

    def setColumns(self, acolumns: int) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#columns

        **int QTextTableFormat::columns() const**

        Returns the number of columns specified by the table format.
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#alignment

        **Qt::Alignment QTextTableFormat::alignment() const**

        Returns the table's alignment.

        **See also** **setAlignment** ().
        """
        ...

    def cellPadding(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#cellPadding

        **qreal QTextTableFormat::cellPadding() const**

        Returns the table's cell padding. This describes the distance between
        the border of a cell and its contents.

        **See also** **setCellPadding** ().
        """
        ...

    def setCellSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#setCellSpacing

        **void QTextTableFormat::setCellSpacing(qreal spacing )**

        Sets the cell **spacing** for the table. This determines the distance
        between adjacent cells.

        This property will be ignored if **borderCollapse**  is enabled.

        **See also** **cellSpacing** ().
        """
        ...

    def cellSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#cellSpacing

        **qreal QTextTableFormat::cellSpacing() const**

        Returns the table's cell spacing. This describes the distance between
        adjacent cells.

        **See also** **setCellSpacing** ().
        """
        ...

    def clearColumnWidthConstraints(self) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#clearColumnWidthConstraints

        **void QTextTableFormat::clearColumnWidthConstraints()**

        Clears the column width constraints for the table.

        **See also** **columnWidthConstraints** () and
        **setColumnWidthConstraints** ().
        """
        ...

    def columnWidthConstraints(self) -> typing.List[QTextLength]:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#columnWidthConstraints

        **QList<QTextLength> QTextTableFormat::columnWidthConstraints() const**

        Returns a list of constraints used by this table format to control the
        appearance of columns in a table.

        **See also** **setColumnWidthConstraints** ().
        """
        ...

    def setColumnWidthConstraints(
        self, constraints: typing.Iterable[QTextLength]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#setColumnWidthConstraints

        **void QTextTableFormat::setColumnWidthConstraints(const
        QList<QTextLength> & constraints )**

        Sets the column width **constraints** for the table.

        **See also** **columnWidthConstraints** () and
        **clearColumnWidthConstraints** ().
        """
        ...

    def columns(self) -> int:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#columns

        **int QTextTableFormat::columns() const**

        Returns the number of columns specified by the table format.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtexttableformat.html#isValid

        **bool QTextTableFormat::isValid() const**

        Returns `true` if this table format is valid; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsPolygonItem(QAbstractGraphicsShapeItem):
    """
    https://doc.qt.io/qt-6/qgraphicspolygonitem.html

    **Detailed Description**

    To set the item's polygon, pass a **QPolygonF**  to QGraphicsPolygonItem's
    constructor, or call the **setPolygon** () function. The **polygon** ()
    function returns the current polygon.

    ![](images/graphicsview-polygonitem.png)

    QGraphicsPolygonItem uses the polygon and the pen width to provide a
    reasonable implementation of **boundingRect** (), **shape** (), and
    **contains** (). The **paint** () function draws the polygon using the
    item's associated pen and brush, which you can set by calling the **setPen**
    () and **setBrush** () functions.

    **See also** **QGraphicsPathItem** , **QGraphicsRectItem** ,
    **QGraphicsEllipseItem** , **QGraphicsTextItem** , **QGraphicsLineItem** ,
    **QGraphicsPixmapItem** , and **Graphics View Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#QGraphicsPolygonItem

        **QGraphicsPolygonItem::QGraphicsPolygonItem(QGraphicsItem * parent =
        nullptr)**

        Constructs a QGraphicsPolygonItem. **parent** is passed to
        **QAbstractGraphicsShapeItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(
        self, polygon: QtGui.QPolygonF, parent: typing.Optional[QGraphicsItem] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#QGraphicsPolygonItem-1

        **QGraphicsPolygonItem::QGraphicsPolygonItem(const QPolygonF & polygon ,
        QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsPolygonItem with **polygon** as the default
        polygon. **parent** is passed to **QAbstractGraphicsShapeItem** 's
        constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#type

        **[override virtual] int QGraphicsPolygonItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsPolygonItem::opaqueArea()
        const**

        Reimplements: **QAbstractGraphicsShapeItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#isObscuredBy

        **[override virtual] bool QGraphicsPolygonItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QAbstractGraphicsShapeItem::isObscuredBy(const
        QGraphicsItem *item) const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#paint

        **[override virtual] void QGraphicsPolygonItem::paint(QPainter * painter
        , const QStyleOptionGraphicsItem * option , QWidget * widget =
        nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def contains(self, point: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#contains

        **[override virtual] bool QGraphicsPolygonItem::contains(const QPointF &
        point ) const**

        Reimplements: **QGraphicsItem::contains(const QPointF &point) const** .
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#shape

        **[override virtual] QPainterPath QGraphicsPolygonItem::shape() const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#boundingRect

        **[override virtual] QRectF QGraphicsPolygonItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    def setFillRule(self, rule: QtCore.Qt.FillRule) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#setFillRule

        **void QGraphicsPolygonItem::setFillRule(Qt::FillRule rule )**

        Sets the fill rule of the polygon to **rule**. The default fill rule is
        **Qt::OddEvenFill** .

        **See also** **fillRule** (), **QPainterPath::fillRule** (), and
        **QPainter::drawPolygon** ().
        """
        ...

    def fillRule(self) -> QtCore.Qt.FillRule:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#fillRule

        **Qt::FillRule QGraphicsPolygonItem::fillRule() const**

        Returns the fill rule of the polygon. The default fill rule is
        **Qt::OddEvenFill** .

        **See also** **setFillRule** (), **QPainterPath::fillRule** (), and
        **QPainter::drawPolygon** ().
        """
        ...

    def setPolygon(self, polygon: QtGui.QPolygonF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#setPolygon

        **void QGraphicsPolygonItem::setPolygon(const QPolygonF & polygon )**

        Sets the item's polygon to be the given **polygon**.

        **See also** **polygon** ().
        """
        ...

    def polygon(self) -> QtGui.QPolygonF:
        """
        https://doc.qt.io/qt-6/qgraphicspolygonitem.html#polygon

        **QPolygonF QGraphicsPolygonItem::polygon() const**

        Returns the item's polygon, or an empty polygon if no polygon has been
        set.

        **See also** **setPolygon** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QMessageAuthenticationCode(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmessageauthenticationcode.html

    **Detailed Description**

    QMessageAuthenticationCode supports all cryptographic hashes which are
    supported by **QCryptographicHash** .

    To generate message authentication code, pass hash algorithm
    **QCryptographicHash::Algorithm**  to constructor, then set key and message
    by **setKey** () and **addData** () functions. Result can be acquired by
    **result** () function.

    **QByteArray**  key = "key";
            **QByteArray**  message = "The quick
    brown fox jumps over the lazy dog";
            ...
    **QMessageAuthenticationCode**  code(**QCryptographicHash** ::Sha1);
    code.setKey(key);
            code.addData(message);
    code.result().toHex();      // returns
    "de7c9b85b8b78aa6bc8a7a36f70a90701c9db4d9"

    Alternatively, this effect can be achieved by providing message, key and
    method to **hash** () method.

    **QMessageAuthenticationCode** ::hash(message, key, **QCryptographicHash**
    ::Sha1).toHex();

    **See also** **QCryptographicHash** .
    """

    def __init__(
        self, method: QCryptographicHash.Algorithm, key: QByteArray = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmessageauthenticationcode.html#QMessageAuthentic
        ationCode

        **QMessageAuthenticationCode::QMessageAuthenticationCode(QCryptographicH
        ash::Algorithm method , const QByteArray & key = QByteArray())**

        Constructs an object that can be used to create a cryptographic hash
        from data using method **method** and key **key**.
        """
        ...

    @staticmethod
    def hash(
        message: QByteArray, key: QByteArray, method: QCryptographicHash.Algorithm
    ) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmessageauthenticationcode.html#hash

        **[static] QByteArray QMessageAuthenticationCode::hash(const QByteArray
        & message , const QByteArray & key , QCryptographicHash::Algorithm
        method )**

        Returns the authentication code for the message **message** using the
        key **key** and the method **method**.
        """
        ...

    def result(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmessageauthenticationcode.html#result

        **QByteArray QMessageAuthenticationCode::result() const**

        Returns the final authentication code.

        **See also** **QByteArray::toHex** ().
        """
        ...

    @typing.overload
    def addData(self, a0: PyQt6.sip.Buffer) -> None:
        """
        https://doc.qt.io/qt-6/qmessageauthenticationcode.html#addData

        **void QMessageAuthenticationCode::addData(const char * data , qsizetype
        length )**

        Adds the first **length** chars of **data** to the message.
        """
        ...

    @typing.overload
    def addData(self, device: QIODevice) -> bool:
        """
        https://doc.qt.io/qt-6/qmessageauthenticationcode.html#addData-1

        **void QMessageAuthenticationCode::addData(const QByteArray & data )**

        This function overloads addData().
        """
        ...

    def setKey(self, key: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qmessageauthenticationcode.html#setKey

        **void QMessageAuthenticationCode::setKey(const QByteArray & key )**

        Sets secret **key**. Calling this method automatically resets the object
        state.
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qmessageauthenticationcode.html#reset

        **void QMessageAuthenticationCode::reset()**

        Resets message data. Calling this method doesn't affect the key.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QAbstractAnimation(QObject):
    """
    https://doc.qt.io/qt-6/qabstractanimation.html

    **Detailed Description**

    The class defines the functions for the functionality shared by all
    animations. By inheriting this class, you can create custom animations that
    plug into the rest of the animation framework.

    The progress of an animation is given by its current time
    (**currentLoopTime** ()), which is measured in milliseconds from the start
    of the animation (0) to its end (**duration** ()). The value is updated
    automatically while the animation is running. It can also be set directly
    with **setCurrentTime** ().

    At any point an animation is in one of three states: **Running** ,
    **Stopped** , or **Paused** \\--as defined by the **State**  enum. The
    current state can be changed by calling **start** (), **stop** (), **pause**
    (), or **resume** (). An animation will always reset its **current time**
    when it is started. If paused, it will continue with the same current time
    when resumed. When an animation is stopped, it cannot be resumed, but will
    keep its current time (until started again). QAbstractAnimation will emit
    **stateChanged** () whenever its state changes.

    An animation can loop any number of times by setting the **loopCount**
    property. When an animation's current time reaches its **duration** (), it
    will reset the current time and keep running. A loop count of 1 (the default
    value) means that the animation will run one time. Note that a duration of
    -1 means that the animation will run until stopped; the current time will
    increase indefinitely. When the current time equals **duration** () and the
    animation is in its final loop, the **Stopped**  state is entered, and the
    **finished** () signal is emitted.

    QAbstractAnimation provides pure virtual functions used by subclasses to
    track the progress of the animation: **duration** () and
    **updateCurrentTime** (). The **duration** () function lets you report a
    duration for the animation (as discussed above). The animation framework
    calls **updateCurrentTime** () when current time has changed. By
    reimplementing this function, you can track the animation progress. Note
    that neither the interval between calls nor the number of calls to this
    function are defined; though, it will normally be 60 updates per second.

    By reimplementing **updateState** (), you can track the animation's state
    changes, which is particularly useful for animations that are not driven by
    time.

    **See also** **QVariantAnimation** , **QPropertyAnimation** ,
    **QAnimationGroup** , and **The Animation Framework** .
    """

    class DeletionPolicy(enum.Enum):
        KeepWhenStopped: QAbstractAnimation = ...
        DeleteWhenStopped: QAbstractAnimation = ...

    class State(enum.Enum):
        Stopped: QAbstractAnimation = ...
        Paused: QAbstractAnimation = ...
        Running: QAbstractAnimation = ...

    class Direction(enum.Enum):
        Forward: QAbstractAnimation = ...
        Backward: QAbstractAnimation = ...

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#QAbstractAnimation

        **QAbstractAnimation::QAbstractAnimation(QObject * parent = nullptr)**

        Constructs the QAbstractAnimation base class, and passes **parent** to
        **QObject** 's constructor.

        **See also** **QVariantAnimation**  and **QAnimationGroup** .
        """
        ...

    def updateDirection(self, direction: "QAbstractAnimation.Direction") -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#updateDirection

        **[virtual protected] void
        QAbstractAnimation::updateDirection(QAbstractAnimation::Direction
        direction )**

        This virtual function is called by **QAbstractAnimation**  when the
        direction of the animation is changed. The **direction** argument is the
        new direction.

        **See also** **setDirection** () and **direction** ().
        """
        ...

    def updateState(
        self, newState: "QAbstractAnimation.State", oldState: "QAbstractAnimation.State"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#updateState

        **[virtual protected] void
        QAbstractAnimation::updateState(QAbstractAnimation::State newState ,
        QAbstractAnimation::State oldState )**

        This virtual function is called by **QAbstractAnimation**  when the
        state of the animation is changed from **oldState** to **newState**.

        **See also** **start** (), **stop** (), **pause** (), and **resume** ().
        """
        ...

    def updateCurrentTime(self, currentTime: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#updateCurrentTime

        **[pure virtual protected] void
        QAbstractAnimation::updateCurrentTime(int currentTime )**

        This pure virtual function is called every time the animation's
        **currentTime** changes.

        **See also** **updateState** ().
        """
        ...

    def event(self, event: "QEvent") -> bool:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#event

        **[override virtual protected] bool QAbstractAnimation::event(QEvent *
        event )**

        Reimplements: **QObject::event** (QEvent *e).
        """
        ...

    def setCurrentTime(self, msecs: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#currentTime-prop

        **[bindable] currentTime : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the current time and progress of the animation

        This property describes the animation's current time. You can change the
        current time by calling setCurrentTime, or you can call **start** () and
        let the animation run, setting the current time automatically as the
        animation progresses.

        The animation's current time starts at 0, and ends at **totalDuration**
        ().

        **Note:** You can bind other properties to currentTime, but it is not
        recommended setting bindings to it. As animation progresses, the
        currentTime is updated automatically, which cancels its bindings.

        **See also** **loopCount**  and **currentLoopTime** ().
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#stop

        **[slot] void QAbstractAnimation::stop()**

        Stops the animation. When the animation is stopped, it emits the
        **stateChanged** () signal, and **state** () returns Stopped. The
        current time is not changed.

        If the animation stops by itself after reaching the end (i.e.,
        **currentLoopTime** () == **duration** () and **currentLoop** () >
        **loopCount** () - 1), the **finished** () signal is emitted.

        **See also** **start** () and **state** ().
        """
        ...

    def setPaused(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#setPaused

        **[slot] void QAbstractAnimation::setPaused(bool paused )**

        If **paused** is true, the animation is paused. If **paused** is false,
        the animation is resumed.

        **See also** **state** (), **pause** (), and **resume** ().
        """
        ...

    def resume(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#resume

        **[slot] void QAbstractAnimation::resume()**

        Resumes the animation after it was paused. When the animation is
        resumed, it emits the resumed() and **stateChanged** () signals. The
        currenttime is not changed.

        **See also** **start** (), **pause** (), and **state** ().
        """
        ...

    def pause(self) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#pause

        **[slot] void QAbstractAnimation::pause()**

        Pauses the animation. When the animation is paused, **state** () returns
        Paused. The value of **currentTime**  will remain unchanged until
        **resume** () or **start** () is called. If you want to continue from
        the current time, call **resume** ().

        **See also** **start** (), **state** (), and **resume** ().
        """
        ...

    def start(self, policy: "QAbstractAnimation.DeletionPolicy" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#start

        **[slot] void
        QAbstractAnimation::start(QAbstractAnimation::DeletionPolicy policy =
        KeepWhenStopped)**

        Starts the animation. The **policy** argument says whether or not the
        animation should be deleted when it's done. When the animation starts,
        the **stateChanged** () signal is emitted, and **state** () returns
        Running. When control reaches the event loop, the animation will run by
        itself, periodically calling **updateCurrentTime** () as the animation
        progresses.

        If the animation is currently stopped or has already reached the end,
        calling start() will rewind the animation and start again from the
        beginning. When the animation reaches the end, the animation will either
        stop, or if the loop level is more than 1, it will rewind and continue
        from the beginning.

        If the animation is already running, this function does nothing.

        **See also** **stop** () and **state** ().
        """
        ...

    def totalDuration(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#totalDuration

        **int QAbstractAnimation::totalDuration() const**

        Returns the total and effective duration of the animation, including the
        loop count.

        **See also** **duration** () and **currentTime** .
        """
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#duration

        **[pure virtual] int QAbstractAnimation::duration() const**

        This pure virtual function returns the duration of the animation, and
        defines for how long **QAbstractAnimation**  should update the current
        time. This duration is local, and does not include the loop count.

        A return value of -1 indicates that the animation has no defined
        duration; the animation should run forever until stopped. This is useful
        for animations that are not time driven, or where you cannot easily
        predict its duration (e.g., event driven audio playback in a game).

        If the animation is a parallel **QAnimationGroup** , the duration will
        be the longest duration of all its animations. If the animation is a
        sequential **QAnimationGroup** , the duration will be the sum of the
        duration of all its animations.

        **Note:** Getter function for property duration.

        **See also** **loopCount** .
        """
        ...

    def currentLoop(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#currentLoop-prop

        **[bindable read-only] currentLoop : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the current loop of the animation

        This property describes the current loop of the animation. By default,
        the animation's loop count is 1, and so the current loop will always be
        0. If the loop count is 2 and the animation runs past its duration, it
        will automatically rewind and restart at current time 0, and current
        loop 1, and so on.

        When the current loop changes, **QAbstractAnimation**  emits the
        **currentLoopChanged** () signal.
        """
        ...

    def setLoopCount(self, loopCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#loopCount-prop

        **[bindable] loopCount : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the loop count of the animation

        This property describes the loop count of the animation as an integer.
        By default this value is 1, indicating that the animation should run
        once only, and then stop. By changing it you can let the animation loop
        several times. With a value of 0, the animation will not run at all, and
        with a value of -1, the animation will loop forever until stopped. It is
        not supported to have loop on an animation that has an undefined
        duration. It will only run once.
        """
        ...

    def loopCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#loopCount-prop

        **[bindable] loopCount : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the loop count of the animation

        This property describes the loop count of the animation as an integer.
        By default this value is 1, indicating that the animation should run
        once only, and then stop. By changing it you can let the animation loop
        several times. With a value of 0, the animation will not run at all, and
        with a value of -1, the animation will loop forever until stopped. It is
        not supported to have loop on an animation that has an undefined
        duration. It will only run once.
        """
        ...

    def currentLoopTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#currentLoopTime

        **int QAbstractAnimation::currentLoopTime() const**

        Returns the current time inside the current loop. It can go from 0 to
        **duration** ().

        **See also** **duration** () and **currentTime** .
        """
        ...

    def currentTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#currentTime-prop

        **[bindable] currentTime : int**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the current time and progress of the animation

        This property describes the animation's current time. You can change the
        current time by calling setCurrentTime, or you can call **start** () and
        let the animation run, setting the current time automatically as the
        animation progresses.

        The animation's current time starts at 0, and ends at **totalDuration**
        ().

        **Note:** You can bind other properties to currentTime, but it is not
        recommended setting bindings to it. As animation progresses, the
        currentTime is updated automatically, which cancels its bindings.

        **See also** **loopCount**  and **currentLoopTime** ().
        """
        ...

    def setDirection(self, direction: "QAbstractAnimation.Direction") -> None:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#direction-prop

        **[bindable] direction : Direction**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the direction of the animation when it is in
        **Running**  state.

        This direction indicates whether the time moves from 0 towards the
        animation duration, or from the value of the duration and towards 0
        after **start** () has been called.

        By default, this property is set to **Forward** .
        """
        ...

    def direction(self) -> "QAbstractAnimation.Direction":
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#direction-prop

        **[bindable] direction : Direction**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the direction of the animation when it is in
        **Running**  state.

        This direction indicates whether the time moves from 0 towards the
        animation duration, or from the value of the duration and towards 0
        after **start** () has been called.

        By default, this property is set to **Forward** .
        """
        ...

    def group(self) -> "QAnimationGroup":
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#group

        **QAnimationGroup *QAbstractAnimation::group() const**

        If this animation is part of a **QAnimationGroup** , this function
        returns a pointer to the group; otherwise, it returns `nullptr`.

        **See also** **QAnimationGroup::addAnimation** ().
        """
        ...

    def state(self) -> "QAbstractAnimation.State":
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#state-prop

        **[bindable read-only] state : State**

        **Note:** This property supports **QProperty**  bindings.

        state of the animation.

        This property describes the current state of the animation. When the
        animation state changes, **QAbstractAnimation**  emits the
        **stateChanged** () signal.

        **Note:** State updates might cause updates of the **currentTime**
        property, which, in turn, can cancel its bindings. So be careful when
        setting bindings to the **currentTime**  property, when you expect the
        state of the animation to change.

        **Member Function Documentation**
        """
        ...

    @property
    def currentLoopChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#currentLoopChanged

        **[signal] void QAbstractAnimation::currentLoopChanged(int currentLoop
        )**

        **QAbstractAnimation**  emits this signal whenever the current loop
        changes. **currentLoop** is the current loop.

        **Note:** Notifier signal for property **currentLoop** .

        **See also** **currentLoop** () and **loopCount** ().
        """
        ...

    @property
    def directionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#directionChanged

        **[signal] void
        QAbstractAnimation::directionChanged(QAbstractAnimation::Direction
        newDirection )**

        **QAbstractAnimation**  emits this signal whenever the direction has
        been changed. **newDirection** is the new direction.

        **Note:** Notifier signal for property **direction** .

        **See also** **direction** .
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#finished

        **[signal] void QAbstractAnimation::finished()**

        **QAbstractAnimation**  emits this signal after the animation has
        stopped and has reached the end.

        This signal is emitted after **stateChanged** ().

        **See also** **stateChanged** ().
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractanimation.html#stateChanged

        **[signal] void
        QAbstractAnimation::stateChanged(QAbstractAnimation::State newState ,
        QAbstractAnimation::State oldState )**

        **QAbstractAnimation**  emits this signal whenever the state of the
        animation has changed from **oldState** to **newState**. This signal is
        emitted after the virtual **updateState** () function is called.

        **Note:** Notifier signal for property **state** .

        **See also** **updateState** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOption(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qstyleoption.html

    **Detailed Description**

    QStyleOption and its subclasses contain all the information that **QStyle**
    functions need to draw a graphical element.

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    The caller of a **QStyle**  function usually creates QStyleOption objects on
    the stack. This combined with Qt's extensive use of **implicit sharing**
    for types such as **QString** , **QPalette** , and **QColor**  ensures that
    no memory allocation needlessly takes place.

    The following code snippet shows how to use a specific QStyleOption subclass
    to paint a push button:

    void MyPushButton::paintEvent(**QPaintEvent**  *)
        {
    **QStyleOptionButton**  option;
            option.initFrom(this);
    option.state = isDown() ? **QStyle** ::State_Sunken : **QStyle**
    ::State_Raised;
            if (isDefault())
                option.features |=
    **QStyleOptionButton** ::DefaultButton;
            option.text = text();
    option.icon = icon();

            **QPainter**  painter(this);
    style()->drawControl(**QStyle** ::CE_PushButton, &option, &painter, this);
    }

    In our example, the control is a **QStyle::CE_PushButton** , and according
    to the **QStyle::drawControl** () documentation the corresponding class is
    **QStyleOptionButton** .

    When reimplementing **QStyle**  functions that take a QStyleOption
    parameter, you often need to cast the QStyleOption to a subclass. For
    safety, you can use **qstyleoption_cast** () to ensure that the pointer type
    is correct. For example:

    void MyStyle::drawPrimitive(PrimitiveElement element,
    const **QStyleOption**  *option,
    **QPainter**  *painter,
                                    const **QWidget**
    *widget)
        {
            if (element == PE_FrameFocusRect) {
                const
    **QStyleOptionFocusRect**  *focusRectOption =
    qstyleoption_cast<const **QStyleOptionFocusRect**  *>(option);
    if (focusRectOption) {
                    // ...
                }
            }
    // ...
        }

    The **qstyleoption_cast** () function will return 0 if the object to which
    `option` points is not of the correct type.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyle**  and **QStylePainter** .
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOption = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOption = ...

    class OptionType(enum.Enum):
        SO_Default: QStyleOption = ...
        SO_FocusRect: QStyleOption = ...
        SO_Button: QStyleOption = ...
        SO_Tab: QStyleOption = ...
        SO_MenuItem: QStyleOption = ...
        SO_Frame: QStyleOption = ...
        SO_ProgressBar: QStyleOption = ...
        SO_ToolBox: QStyleOption = ...
        SO_Header: QStyleOption = ...
        SO_DockWidget: QStyleOption = ...
        SO_ViewItem: QStyleOption = ...
        SO_TabWidgetFrame: QStyleOption = ...
        SO_TabBarBase: QStyleOption = ...
        SO_RubberBand: QStyleOption = ...
        SO_ToolBar: QStyleOption = ...
        SO_Complex: QStyleOption = ...
        SO_Slider: QStyleOption = ...
        SO_SpinBox: QStyleOption = ...
        SO_ToolButton: QStyleOption = ...
        SO_ComboBox: QStyleOption = ...
        SO_TitleBar: QStyleOption = ...
        SO_GroupBox: QStyleOption = ...
        SO_ComplexCustomBase: QStyleOption = ...
        SO_GraphicsItem: QStyleOption = ...
        SO_SizeGrip: QStyleOption = ...
        SO_CustomBase: QStyleOption = ...

    direction: QtCore = ...
    fontMetrics: QtGui = ...
    palette: QtGui = ...
    rect: QtCore = ...
    state: QStyle = ...
    styleObject: QtCore = ...
    type: int = ...
    version: int = ...

    @typing.overload
    def __init__(self, version: int = ..., type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoption.html#QStyleOption

        **QStyleOption::QStyleOption(int version = QStyleOption::Version, int
        type = SO_Default)**

        Constructs a QStyleOption with the specified **version** and **type**.

        The version has no special meaning for QStyleOption; it can be used by
        subclasses to distinguish between different version of the same option
        type.

        The **state**  member variable is initialized to **QStyle::State_None**
        .

        **See also** **version**  and **type** .
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOption") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoption.html#QStyleOption-1

        **QStyleOption::QStyleOption(const QStyleOption & other )**

        Constructs a copy of **other**.
        """
        ...

    def initFrom(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoption.html#initFrom

        **void QStyleOption::initFrom(const QWidget * widget )**

        Initializes the **state** , **direction** , **rect** , **palette** ,
        **fontMetrics**  and **styleObject**  member variables based on the
        specified **widget**.

        This is a convenience function; the member variables can also be
        initialized manually.

        **See also** **QWidget::layoutDirection** (), **QWidget::rect** (),
        **QWidget::palette** (), and **QWidget::fontMetrics** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPageSize(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpagesize.html

    **Detailed Description**

    This class implements support for the set of standard page sizes as defined
    in the Adobe Postscript PPD Standard v4.3. It defines the standard set of
    page sizes in points, millimeters and inches and ensures these sizes are
    consistently used. Other size units can be used but will be calculated
    results and so may not always be consistent. The defined point sizes are
    always a integer, all other sizes can be fractions of a unit.

    The defined size is always in width x height order with no implied page
    orientation. Note that it is possible for page sizes to be defined where the
    width is greater than the height, such as **QPageSize::Ledger** , so you
    cannot rely on comparing the width and height values to determine page
    orientation.

    For example, A4 is defined by the standard as 210mm x 297mm, 8.27in x
    11.69in, or 595pt x 842pt.

    You can also define custom page sizes with custom names in any units you
    want and this unit size will be preserved and used as the base for all other
    unit size calculations.

    When creating a QPageSize using a custom **QSize**  you can choose if you
    want QPageSize to try match the size to a standard page size. By default
    QPaperSize uses a **FuzzyMatch**  mode where it will match a given page size
    to a standard page size if it falls within 3 postscript points of a defined
    standard size. You can override this to request only an exact match but this
    is not recommended as conversions between units can easily lose 3 points and
    result in incorrect page sizes.

    A QPageSize instance may also be obtained by querying the supported page
    sizes for a print device. In this case the localized name returned is that
    defined by the printer itself. Note that the print device may not support
    the current default locale language.

    The class also provides convenience methods for converting page size IDs to
    and from various unit sizes.

    **See also** **QPagedPaintDevice**  and **QPdfWriter** .
    """

    class SizeMatchPolicy(enum.Enum):
        FuzzyMatch: QPageSize = ...
        FuzzyOrientationMatch: QPageSize = ...
        ExactMatch: QPageSize = ...

    class Unit(enum.Enum):
        Millimeter: QPageSize = ...
        Point: QPageSize = ...
        Inch: QPageSize = ...
        Pica: QPageSize = ...
        Didot: QPageSize = ...
        Cicero: QPageSize = ...

    class PageSizeId(enum.Enum):
        A4: QPageSize = ...
        B5: QPageSize = ...
        Letter: QPageSize = ...
        Legal: QPageSize = ...
        Executive: QPageSize = ...
        A0: QPageSize = ...
        A1: QPageSize = ...
        A2: QPageSize = ...
        A3: QPageSize = ...
        A5: QPageSize = ...
        A6: QPageSize = ...
        A7: QPageSize = ...
        A8: QPageSize = ...
        A9: QPageSize = ...
        B0: QPageSize = ...
        B1: QPageSize = ...
        B10: QPageSize = ...
        B2: QPageSize = ...
        B3: QPageSize = ...
        B4: QPageSize = ...
        B6: QPageSize = ...
        B7: QPageSize = ...
        B8: QPageSize = ...
        B9: QPageSize = ...
        C5E: QPageSize = ...
        Comm10E: QPageSize = ...
        DLE: QPageSize = ...
        Folio: QPageSize = ...
        Ledger: QPageSize = ...
        Tabloid: QPageSize = ...
        Custom: QPageSize = ...
        A10: QPageSize = ...
        A3Extra: QPageSize = ...
        A4Extra: QPageSize = ...
        A4Plus: QPageSize = ...
        A4Small: QPageSize = ...
        A5Extra: QPageSize = ...
        B5Extra: QPageSize = ...
        JisB0: QPageSize = ...
        JisB1: QPageSize = ...
        JisB2: QPageSize = ...
        JisB3: QPageSize = ...
        JisB4: QPageSize = ...
        JisB5: QPageSize = ...
        JisB6: QPageSize = ...
        JisB7: QPageSize = ...
        JisB8: QPageSize = ...
        JisB9: QPageSize = ...
        JisB10: QPageSize = ...
        AnsiC: QPageSize = ...
        AnsiD: QPageSize = ...
        AnsiE: QPageSize = ...
        LegalExtra: QPageSize = ...
        LetterExtra: QPageSize = ...
        LetterPlus: QPageSize = ...
        LetterSmall: QPageSize = ...
        TabloidExtra: QPageSize = ...
        ArchA: QPageSize = ...
        ArchB: QPageSize = ...
        ArchC: QPageSize = ...
        ArchD: QPageSize = ...
        ArchE: QPageSize = ...
        Imperial7x9: QPageSize = ...
        Imperial8x10: QPageSize = ...
        Imperial9x11: QPageSize = ...
        Imperial9x12: QPageSize = ...
        Imperial10x11: QPageSize = ...
        Imperial10x13: QPageSize = ...
        Imperial10x14: QPageSize = ...
        Imperial12x11: QPageSize = ...
        Imperial15x11: QPageSize = ...
        ExecutiveStandard: QPageSize = ...
        Note: QPageSize = ...
        Quarto: QPageSize = ...
        Statement: QPageSize = ...
        SuperA: QPageSize = ...
        SuperB: QPageSize = ...
        Postcard: QPageSize = ...
        DoublePostcard: QPageSize = ...
        Prc16K: QPageSize = ...
        Prc32K: QPageSize = ...
        Prc32KBig: QPageSize = ...
        FanFoldUS: QPageSize = ...
        FanFoldGerman: QPageSize = ...
        FanFoldGermanLegal: QPageSize = ...
        EnvelopeB4: QPageSize = ...
        EnvelopeB5: QPageSize = ...
        EnvelopeB6: QPageSize = ...
        EnvelopeC0: QPageSize = ...
        EnvelopeC1: QPageSize = ...
        EnvelopeC2: QPageSize = ...
        EnvelopeC3: QPageSize = ...
        EnvelopeC4: QPageSize = ...
        EnvelopeC6: QPageSize = ...
        EnvelopeC65: QPageSize = ...
        EnvelopeC7: QPageSize = ...
        Envelope9: QPageSize = ...
        Envelope11: QPageSize = ...
        Envelope12: QPageSize = ...
        Envelope14: QPageSize = ...
        EnvelopeMonarch: QPageSize = ...
        EnvelopePersonal: QPageSize = ...
        EnvelopeChou3: QPageSize = ...
        EnvelopeChou4: QPageSize = ...
        EnvelopeInvite: QPageSize = ...
        EnvelopeItalian: QPageSize = ...
        EnvelopeKaku2: QPageSize = ...
        EnvelopeKaku3: QPageSize = ...
        EnvelopePrc1: QPageSize = ...
        EnvelopePrc2: QPageSize = ...
        EnvelopePrc3: QPageSize = ...
        EnvelopePrc4: QPageSize = ...
        EnvelopePrc5: QPageSize = ...
        EnvelopePrc6: QPageSize = ...
        EnvelopePrc7: QPageSize = ...
        EnvelopePrc8: QPageSize = ...
        EnvelopePrc9: QPageSize = ...
        EnvelopePrc10: QPageSize = ...
        EnvelopeYou4: QPageSize = ...
        AnsiA: QPageSize = ...
        AnsiB: QPageSize = ...
        EnvelopeC5: QPageSize = ...
        EnvelopeDL: QPageSize = ...
        Envelope10: QPageSize = ...
        LastPageSize: QPageSize = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpagesize.html#QPageSize

        **QPageSize::QPageSize()**

        Creates a null QPageSize.
        """
        ...

    @typing.overload
    def __init__(self, pageSizeId: "QPageSize.PageSizeId") -> None:
        """
        https://doc.qt.io/qt-6/qpagesize.html#QPageSize-1

        **QPageSize::QPageSize(QPageSize::PageSizeId pageSize )**

        Creates a QPageSize of the standard **pageSize**.

        If **pageSize** is **QPageSize::Custom**  then the resulting QPageSize
        will not be valid. Use the custom size constructor instead.
        """
        ...

    @typing.overload
    def __init__(
        self,
        pointSize: QtCore.QSize,
        name: str = ...,
        matchPolicy: "QPageSize.SizeMatchPolicy" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpagesize.html#QPageSize-2

        **QPageSize::QPageSize(const QSize & pointSize , const QString & name =
        QString(), QPageSize::SizeMatchPolicy matchPolicy = FuzzyMatch)**

        Creates a QPageSize of the given **pointSize** in Points using the
        matching **matchPolicy**.

        If the given **pointSize** matches a standard **QPageSize::PageSizeId**
        , then that page size will be used. Note that if the **matchPolicy** is
        **FuzzyMatch**  this may result in the **pointSize** being adjusted to
        the standard size. To prevent this happening use a **matchPolicy** of
        **ExactMatch**  instead.

        If the given **pointSize** is not a standard **QPageSize::PageSizeId**
        then a **QPageSize::Custom**  size will be created.

        If **name** is null then the standard localized name will be used. If a
        custom page size then a custom name in the format "Custom (width x
        height)" will be created.

        The **matchPolicy** defaults to **FuzzyMatch** .
        """
        ...

    @typing.overload
    def __init__(
        self,
        size: QtCore.QSizeF,
        units: "QPageSize.Unit",
        name: str = ...,
        matchPolicy: "QPageSize.SizeMatchPolicy" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpagesize.html#QPageSize-3

        **QPageSize::QPageSize(const QSizeF & size , QPageSize::Unit units ,
        const QString & name = QString(), QPageSize::SizeMatchPolicy matchPolicy
        = FuzzyMatch)**

        Creates a custom page of the given **size** in **units**.

        If the given **size** matches a standard **QPageSize::PageSizeId** ,
        then that page size will be used. Note that if the **matchPolicy** is
        **FuzzyMatch**  this may result in the **size** being adjusted to the
        standard size. To prevent this happening use a **matchPolicy** of
        **ExactMatch**  instead.

        If the given **size** is not a standard **QPageSize::PageSizeId**  then
        a **QPageSize::Custom**  size will be created. The original unit size
        will be preserved and used as the base for all other unit size
        calculations.

        If **name** is null then a custom name will be created in the form
        "Custom (width x height)" where the size is expressed in units provided.
        """
        ...

    @typing.overload
    def __init__(self, other: "QPageSize") -> None:
        """
        https://doc.qt.io/qt-6/qpagesize.html#QPageSize-4

        **QPageSize::QPageSize(const QPageSize & other )**

        Copy constructor, copies **other** to this.
        """
        ...

    def rectPixels(self, resolution: int) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpagesize.html#rectPixels

        **QRect QPageSize::rectPixels(int resolution ) const**

        Returns the page rectangle in Device Pixels at the given **resolution**.

        If the **QPageSize**  is invalid then the **QRect**  will be invalid.
        """
        ...

    def rectPoints(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qpagesize.html#rectPoints

        **QRect QPageSize::rectPoints() const**

        Returns the page rectangle in Postscript Points (1/72 of an inch).

        If the **QPageSize**  is invalid then the **QRect**  will be invalid.
        """
        ...

    def rect(self, units: "QPageSize.Unit") -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpagesize.html#rect

        **QRectF QPageSize::rect(QPageSize::Unit units ) const**

        Returns the page rectangle in the required **units**.

        If the **QPageSize**  is invalid then the **QRect**  will be invalid.
        """
        ...

    @typing.overload
    def sizePixels(self, resolution: int) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qpagesize.html#sizePixels

        **QSize QPageSize::sizePixels(int resolution ) const**

        Returns the size of the page in Device Pixels at the given
        **resolution**.

        If the **QPageSize**  is invalid then the **QSize**  will be invalid.
        """
        ...

    @typing.overload
    @staticmethod
    def sizePixels(pageSizeId: "QPageSize.PageSizeId", resolution: int) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qpagesize.html#sizePixels-1

        **[static] QSize QPageSize::sizePixels(QPageSize::PageSizeId pageSizeId
        , int resolution )**

        Returns the size of the standard **pageSizeId** in Device Pixels for the
        given **resolution**.
        """
        ...

    @typing.overload
    def sizePoints(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qpagesize.html#sizePoints

        **QSize QPageSize::sizePoints() const**

        Returns the size of the page in Postscript Points (1/72 of an inch).

        If the **QPageSize**  is invalid then the **QSize**  will be invalid.
        """
        ...

    @typing.overload
    @staticmethod
    def sizePoints(pageSizeId: "QPageSize.PageSizeId") -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qpagesize.html#sizePoints-1

        **[static] QSize QPageSize::sizePoints(QPageSize::PageSizeId pageSizeId
        )**

        Returns the size of the standard **pageSizeId** in Points.
        """
        ...

    @typing.overload
    def size(self, units: "QPageSize.Unit") -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qpagesize.html#size

        **QSizeF QPageSize::size(QPageSize::Unit units ) const**

        Returns the size of the page in the required **units**.

        If the **QPageSize**  is invalid then the **QSizeF**  will be invalid.
        """
        ...

    @typing.overload
    @staticmethod
    def size(
        pageSizeId: "QPageSize.PageSizeId", units: "QPageSize.Unit"
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qpagesize.html#size-1

        **[static] QSizeF QPageSize::size(QPageSize::PageSizeId pageSizeId ,
        QPageSize::Unit units )**

        Returns the size of the standard **pageSizeId** in the requested
        **units**.
        """
        ...

    @typing.overload
    def definitionUnits(self) -> "QPageSize.Unit":
        """
        https://doc.qt.io/qt-6/qpagesize.html#definitionUnits

        **QPageSize::Unit QPageSize::definitionUnits() const**

        Returns the definition units of the page size.

        For a standard page size this will be the units as defined in the
        relevant standard, i.e. ISO A4 will be defined in millimeters while ANSI
        Letter will be defined in inches.

        For a custom page size this will be the original units used to create
        the page size object.

        If the **QPageSize**  is invalid then the **QPageSize::Unit**  will be
        invalid.

        **See also** **definitionSize** ().
        """
        ...

    @typing.overload
    @staticmethod
    def definitionUnits(pageSizeId: "QPageSize.PageSizeId") -> "QPageSize.Unit":
        """
        https://doc.qt.io/qt-6/qpagesize.html#definitionUnits-1

        **[static] QPageSize::Unit
        QPageSize::definitionUnits(QPageSize::PageSizeId pageSizeId )**

        Returns the definition units of the standard **pageSizeId**.

        To obtain the definition size, call **QPageSize::definitionSize** ().
        """
        ...

    @typing.overload
    def definitionSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qpagesize.html#definitionSize

        **QSizeF QPageSize::definitionSize() const**

        Returns the definition size of the page size.

        For a standard page size this will be the size as defined in the
        relevant standard, i.e. ISO A4 will be defined in millimeters while ANSI
        Letter will be defined in inches.

        For a custom page size this will be the original size used to create the
        page size object.

        If the **QPageSize**  is invalid then the **QSizeF**  will be invalid.

        **See also** **definitionUnits** ().
        """
        ...

    @typing.overload
    @staticmethod
    def definitionSize(pageSizeId: "QPageSize.PageSizeId") -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qpagesize.html#definitionSize-1

        **[static] QSizeF QPageSize::definitionSize(QPageSize::PageSizeId
        pageSizeId )**

        Returns the definition size of the standard **pageSizeId**.

        To obtain the definition units, call **QPageSize::definitionUnits** ().
        """
        ...

    @typing.overload
    def windowsId(self) -> int:
        """
        https://doc.qt.io/qt-6/qpagesize.html#windowsId

        **int QPageSize::windowsId() const**

        Returns the Windows DMPAPER enum value for the page size.

        Not all valid PPD page sizes have a Windows equivalent, in which case 0
        will be returned.

        If the **QPageSize**  is invalid then the Windows ID will be 0.

        **See also** **id** ().
        """
        ...

    @typing.overload
    @staticmethod
    def windowsId(pageSizeId: "QPageSize.PageSizeId") -> int:
        """
        https://doc.qt.io/qt-6/qpagesize.html#windowsId-1

        **[static] int QPageSize::windowsId(QPageSize::PageSizeId pageSizeId )**

        Returns the Windows DMPAPER enum value of the standard **pageSizeId**.

        Not all valid PPD page sizes have a Windows equivalent, in which case 0
        will be returned.
        """
        ...

    @typing.overload
    def id(self) -> "QPageSize.PageSizeId":
        """
        https://doc.qt.io/qt-6/qpagesize.html#id

        **QPageSize::PageSizeId QPageSize::id() const**

        Returns the standard **QPageSize::PageSizeId**  of the page, or
        **QPageSize::Custom** .

        If the **QPageSize**  is invalid then the ID will be
        **QPageSize::Custom** .
        """
        ...

    @typing.overload
    @staticmethod
    def id(
        pointSize: QtCore.QSize, matchPolicy: "QPageSize.SizeMatchPolicy" = ...
    ) -> "QPageSize.PageSizeId":
        """
        https://doc.qt.io/qt-6/qpagesize.html#id-1

        **[static] QPageSize::PageSizeId QPageSize::id(const QSize & pointSize ,
        QPageSize::SizeMatchPolicy matchPolicy = FuzzyMatch)**

        Returns the standard **QPageSize::PageSizeId**  of the given
        **pointSize** in points using the given **matchPolicy**.

        If using **FuzzyMatch**  then the point size of the **PageSizeId**
        returned may not exactly match the **pointSize** you passed in. You
        should call **QPageSize::sizePoints** () using the returned
        **PageSizeId**  to find out the actual point size of the **PageSizeId**
        before using it in any calculations.
        """
        ...

    @typing.overload
    @staticmethod
    def id(
        size: QtCore.QSizeF,
        units: "QPageSize.Unit",
        matchPolicy: "QPageSize.SizeMatchPolicy" = ...,
    ) -> "QPageSize.PageSizeId":
        """
        https://doc.qt.io/qt-6/qpagesize.html#id-2

        **[static] QPageSize::PageSizeId QPageSize::id(const QSizeF & size ,
        QPageSize::Unit units , QPageSize::SizeMatchPolicy matchPolicy =
        FuzzyMatch)**

        Returns the standard **QPageSize::PageSizeId**  of the given **size** in
        **units** using the given **matchPolicy**.

        If using **FuzzyMatch**  then the unit size of the **PageSizeId**
        returned may not exactly match the **size** you passed in. You should
        call **QPageSize::size** () using the returned **PageSizeId**  to find
        out the actual unit size of the **PageSizeId**  before using it in any
        calculations.
        """
        ...

    @typing.overload
    @staticmethod
    def id(windowsId: int) -> "QPageSize.PageSizeId":
        """
        https://doc.qt.io/qt-6/qpagesize.html#id-3

        **[static] QPageSize::PageSizeId QPageSize::id(int windowsId )**

        Returns the **PageSizeId**  for the given Windows DMPAPER enum value
        **windowsId**.

        If there is no matching **PageSizeId**  then **QPageSize::Custom**  is
        returned.
        """
        ...

    @typing.overload
    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qpagesize.html#name

        **QString QPageSize::name() const**

        Returns a localized human-readable name for the page size.

        If the **QPageSize**  instance was obtained from a print device then the
        name used is that provided by the print device. Note that a print device
        may not support the current default locale language.

        If the **QPageSize**  is invalid then the name will be an empty string.
        """
        ...

    @typing.overload
    @staticmethod
    def name(pageSizeId: "QPageSize.PageSizeId") -> str:
        """
        https://doc.qt.io/qt-6/qpagesize.html#name-1

        **[static] QString QPageSize::name(QPageSize::PageSizeId pageSizeId )**

        Returns the localized name of the standard **pageSizeId**.

        If the **QPageSize**  is invalid then the name will be empty.
        """
        ...

    @typing.overload
    def key(self) -> str:
        """
        https://doc.qt.io/qt-6/qpagesize.html#key

        **QString QPageSize::key() const**

        Returns the unique key of the page size.

        By default this is the PPD standard mediaOption keyword for the page
        size, or the PPD custom format key. If the **QPageSize**  instance was
        obtained from a print device then this will be the key provided by the
        print device and may differ from the standard key.

        If the **QPageSize**  is invalid then the key will be an empty string.

        This key should never be shown to end users, it is an internal key only.
        For a human-readable name use **name** ().

        **See also** **name** ().
        """
        ...

    @typing.overload
    @staticmethod
    def key(pageSizeId: "QPageSize.PageSizeId") -> str:
        """
        https://doc.qt.io/qt-6/qpagesize.html#key-1

        **[static] QString QPageSize::key(QPageSize::PageSizeId pageSizeId )**

        Returns the PPD mediaOption keyword of the standard **pageSizeId**.

        If the **QPageSize**  is invalid then the key will be empty.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpagesize.html#isValid

        **bool QPageSize::isValid() const**

        Returns `true` if this page size is valid.

        The page size may be invalid if created with an invalid **PageSizeId** ,
        or a negative or invalid **QSize**  or **QSizeF** , or the null
        constructor.
        """
        ...

    def isEquivalentTo(self, other: "QPageSize") -> bool:
        """
        https://doc.qt.io/qt-6/qpagesize.html#isEquivalentTo

        **bool QPageSize::isEquivalentTo(const QPageSize & other ) const**

        Returns `true` if this page is equivalent to the **other** page, i.e. if
        the page has the same size regardless of other attributes like name.
        """
        ...

    def swap(self, other: "QPageSize") -> None:
        """
        https://doc.qt.io/qt-6/qpagesize.html#swap

        **void QPageSize::swap(QPageSize & other )**

        Swaps this **QPageSize**  with **other**. This function is very fast and
        never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore


class QQuickItemGrabResult(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qquickitemgrabresult.html

    **Detailed Description**

    **See also** **QQuickItem::grabToImage** ().
    """

    def event(self, a0: QtCore.QEvent) -> bool:
        ...

    @typing.overload
    def saveToFile(self, fileName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qquickitemgrabresult.html#saveToFile

        **[invokable] bool QQuickItemGrabResult::saveToFile(const QString &
        fileName ) const**

        Saves the grab result as an image to **fileName**. Returns `true` if
        successful; otherwise returns `false`.

        **Note:** In Qt versions prior to 5.9, this function is marked as
        non-`const`.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    @typing.overload
    def saveToFile(self, fileName: QtCore.QUrl) -> bool:
        """
        https://doc.qt.io/qt-6/qquickitemgrabresult.html#saveToFile-1

        **[invokable, since 6.2] bool QQuickItemGrabResult::saveToFile(const
        QUrl & filePath ) const**

        Saves the grab result as an image to **filePath** , which must refer to
        a **local file name**  with a **supported image format**  extension.
        Returns `true` if successful; otherwise returns `false`.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 6.2.
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qquickitemgrabresult.html#url-prop

        **[read-only] url : const QUrl**

        This property holds a URL which can be used in conjunction with URL
        based image consumers, such as the QtQuick::Image type.

        The URL is valid until the **QQuickItemGrabResult**  object is deleted.

        The URL does not represent a valid file or location to read it from, it
        is primarily a key to access images through Qt Quick's image-based
        types.

        **Access functions:**

        QUrl **url** () const

        **Member Function Documentation**
        """
        ...

    def image(self) -> QtGui.QImage:
        """
        https://doc.qt.io/qt-6/qquickitemgrabresult.html#image-prop

        **[read-only] image : const QImage**

        This property holds the pixel results from a grab.

        If the grab is not yet complete or if it failed, a null image is
        returned (`image.isNull()` will return `true`).

        **Access functions:**

        QImage **image** () const
        """
        ...

    @property
    def ready(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qquickitemgrabresult.html#ready

        **[signal] void QQuickItemGrabResult::ready()**

        This signal is emitted when the grab has completed.
        """
        ...
